package cn.rankin.productservice.proxy;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.product.CourseSubRelationDTO;
import cn.rankin.common.utils.enums.CourseSubTypeEnum;
import cn.rankin.productservice.entity.CourseSubRelation;
import cn.rankin.productservice.entity.CourseSupportRelation;
import cn.rankin.productservice.entity.Lesson;
import cn.rankin.productservice.entity.Support;
import cn.rankin.productservice.service.CourseSubRelationService;
import cn.rankin.productservice.service.CourseSupportRelationService;
import cn.rankin.productservice.service.LessonService;
import cn.rankin.productservice.service.SupportService;
import cn.rankin.productservice.vo.CourseSubItemVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

import static cn.rankin.productservice.utils.DTOConverter.convert;

@Service
public class CourseServiceProxy {

    @Autowired
    private CourseSubRelationService courseSubRelationService;

    @Autowired
    private LessonService lessonService;

    @Autowired
    private CourseSupportRelationService courseSupportRelationService;

    @Autowired
    private SupportService supportService;

    // find sub item by courseId
    public List<CourseSubItemVo> findSubItemVo(String courseId) {
        List<CourseSubItemVo> subItemVoList = new ArrayList<>();

        List<CourseSubRelation> courseSubRelationList = courseSubRelationService.findByCourseId(courseId);
        if (courseSubRelationList == null || courseSubRelationList.size() == 0) {
            return subItemVoList;
        }

        List<String> lessonIdList = new ArrayList<>();
        courseSubRelationList.forEach( relation -> {
            if (CourseSubTypeEnum.LESSON.equals(relation.getType())) {
                lessonIdList.add(relation.getSubId());
            }
        });

        APIResult<List<Lesson>> lessonResult = lessonService.findByIds(lessonIdList);
        List<Lesson> lessonList = lessonResult.getData();
        if (lessonList != null && lessonList.size() > 0) {
            lessonList.forEach(lesson -> subItemVoList.add(convert(lesson)));
        }

        return subItemVoList;
    }

    // find support by courseId
    public List<Support> findSupportList(String courseId) {

        List<CourseSupportRelation> supportRelationList = courseSupportRelationService.findByCourseId(courseId);
        if (supportRelationList == null || supportRelationList.size() == 0) {
            return new ArrayList<>();
        }

        List<String> supportIdList = new ArrayList<>();
        supportRelationList.forEach( relation -> supportIdList.add(relation.getSupportId()));
        APIResult<List<Support>> supportResult = supportService.findByIds(supportIdList);

        return supportResult.getData();
    }

    // 更新二级关系
    @Transactional
    public APIResult<List<CourseSubItemVo>> updateSubRelation(String courseId, List<CourseSubRelationDTO> subRelationDTOList) {
        // TODO: 暂时不考虑单元
        if (subRelationDTOList == null) {
            return APIResult.ok();
        }else if (subRelationDTOList.size() == 0) {
            courseSubRelationService.deleteByCourseId(courseId);
            return APIResult.ok(new ArrayList<>());
        }

        List<String> lessonIdList = new ArrayList<>();
        subRelationDTOList.forEach( relation -> {
            if (CourseSubTypeEnum.LESSON.equals(relation.getType())) {
                lessonIdList.add(relation.getId());
            }
        });

        // 查课
        APIResult<List<Lesson>> lessonResult = lessonService.findByIds(lessonIdList);
        List<Lesson> lessonList = lessonResult.getData();
        if (lessonList == null || lessonList.size() != lessonIdList.size()) {
            return APIResult.error(APICodeManager.error("存在错误的课"));
        }

        courseSubRelationService.update(courseId, subRelationDTOList);

        List<CourseSubItemVo> subItemVoList = new ArrayList<>();
        lessonResult.getData().forEach( lesson -> {
            subItemVoList.add(convert(lesson));
        });

        return APIResult.ok(subItemVoList);
    }

    // 更新周边关系
    @Transactional
    public APIResult<List<Support>> updateSupportRelation(String courseId, List<String> supportIdList) {
        if (supportIdList == null) {
            return APIResult.ok();
        }

        List<Support> supportList = new ArrayList<>();
        if (supportIdList.size() == 0) {
            courseSupportRelationService.deleteByCourseId(courseId);
        }else {
            APIResult<List<Support>> supportResult = supportService.findByIds(supportIdList);
            supportList = supportResult.getData();
            if (supportList == null || supportList.size() != supportIdList.size()) {
                return APIResult.error(APICodeManager.error("存在错误的周边"));
            }
            courseSupportRelationService.update(courseId, supportIdList);
        }

        return APIResult.ok(supportList);
    }
}
