package cn.rankin.productservice.proxy;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.product.ItemPriceDTO;
import cn.rankin.common.utils.enums.EnumUtil;
import cn.rankin.common.utils.enums.ItemTypeEnum;
import cn.rankin.productservice.entity.Item;
import cn.rankin.productservice.entity.ItemPrice;
import cn.rankin.productservice.entity.Support;
import cn.rankin.productservice.entity.Tag;
import cn.rankin.productservice.service.ItemPriceService;
import cn.rankin.productservice.service.ItemService;
import cn.rankin.productservice.service.ItemTagRelationService;
import cn.rankin.productservice.service.TagService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

@Service
public class ItemServiceProxy {

    @Autowired
    private ItemService itemService;

    @Autowired
    private ItemPriceService itemPriceService;

    @Autowired
    private ItemTagRelationService tagRelationService;

    @Autowired
    private TagService tagService;

    public Item loadItem(String itemId) {
        Item item = itemService.findOne(itemId);
        if (item == null) {
            return null;
        }

        ItemTypeEnum itemType = item.getType();
        if (itemType == ItemTypeEnum.COURSE) {

        }

        return null;
    }

    public List<Support> getSupport(Item item) {
        return null;
    }

    public List<Tag> getTagList(Item item) {
        return null;
    }

    @Transactional
    public APIResult<List<ItemPrice>> updatePrice(String itemId, List<ItemPriceDTO> priceDTOList) {
        List<ItemPrice> priceList = new ArrayList<>();
        if (priceDTOList == null) {
            return APIResult.ok();
        }

        if (priceDTOList.size() == 0) {
            itemPriceService.deleteByItemId(itemId);
        }else {
            priceList = itemPriceService.update(itemId, priceDTOList).getData();
        }

        return APIResult.ok(priceList);
    }

    @Transactional
    public APIResult<List<Tag>> updateTagRelation(String itemId, List<String> tagIdList) {
        List<Tag> tagList = new ArrayList<>();
        if (tagIdList == null) {
            return APIResult.ok();
        }

        if (tagIdList.size() == 0) {
            tagRelationService.deleteByItemId(itemId);
        }else {
            APIResult<List<Tag>> tagResult = tagService.findByIds(tagIdList);
            tagList = tagResult.getData();
            if (tagList == null || tagList.size() != tagIdList.size()) {
                return APIResult.error(APICodeManager.error("包含错误的标签"));
            }

            Item item = itemService.findById(itemId).getData();
            if (item == null) {
                return APIResult.error(APICodeManager.error("商品不存在"));
            }

            String merchantId = item.getMerchantId();
            ItemTypeEnum itemType = item.getType();
            for (int i = 0; i < tagList.size(); i++) {
                Tag tag = tagList.get(i);
//                if (!tag.getMerchantId().equals(merchantId) || !EnumUtil.compare(itemType, tag.getType())) {
//                    return APIResult.error(APICodeManager.error("包含错误的标签"));
//                }
            }

            tagRelationService.updateByItem(itemId, tagIdList);
        }

        return APIResult.ok(tagList);
    }
}
