package cn.rankin.productservice.repository;

import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.jpa.BasicJpaRepository;
import cn.rankin.productservice.entity.ItemTagRelation;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

public interface ItemTagRelationRepository extends BasicJpaRepository<ItemTagRelation, String> {

    List<ItemTagRelation> findAllByItemId(String itemId);

    @Query(value = "select r from ItemTagRelation r where r.tagId = :tagId and r.status = :status")
    List<ItemTagRelation> findByTagId(@Param("tagId") String tagId, @Param("status") BaseStatusEnum status);

    List<ItemTagRelation> findAllByTagId(String tagId);

    @Transactional
    @Modifying(clearAutomatically = true)
    @Query(value = "update ItemTagRelation r set r.status = :status where r.itemId = :itemId")
    Integer deleteByItemId(@Param("itemId") String itemId, @Param("status")BaseStatusEnum status);

    @Transactional
    @Modifying(clearAutomatically = true)
    @Query(value = "update ItemTagRelation r set r.status = :status where r.tagId = :tagId")
    Integer deleteByTagId(@Param("tagId") String tagId, @Param("status") BaseStatusEnum status);
}
