package cn.rankin.productservice.repository;

import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.jpa.BasicJpaRepository;
import cn.rankin.productservice.entity.Tag;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;


public interface TagRepository extends BasicJpaRepository<Tag, String> {

    List<Tag> findByIdss(List<String> tagIdList, BaseStatusEnum status);

    @Query(value = "select t from Tag t where t.groupId = :groupId and t.status = :status")
    List<Tag> findNormalByGroupId(@Param("groupId") String groupId, @Param("status") BaseStatusEnum status);

    @Query(value = "select t from Tag t where t.id in (:ids) and t.status = :status order by t.sort asc")
    List<Tag> findByIdIn(@Param("ids") List<String> ids, @Param("status") BaseStatusEnum status);

    @Transactional
    @Modifying(clearAutomatically = true)
    @Query(value = "update Tag t set t.status = :status where t.id = :id")
    Integer updateStatusById(@Param("id") String id, @Param("status") BaseStatusEnum status);

    @Transactional
    @Modifying(clearAutomatically = true)
    @Query(value = "update Tag t set t.status = :status where t.groupId = :groupId")
    Integer deleteByGroupId(@Param("groupId") String groupId, @Param("status") BaseStatusEnum status);
}
