package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.GroupDTO;
import cn.rankin.common.utils.enums.BaseOrderEnum;
import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.util.JpaSortUtil;
import cn.rankin.productservice.entity.Group;
import cn.rankin.productservice.repository.GroupRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.LinkedHashMap;
import java.util.List;

import static cn.rankin.productservice.utils.DTOConverter.convert;

@Service
public class GroupService {

    @Autowired
    private GroupRepository groupRepository;

    public APIResult<Group> findById(String id) {
        Group group = groupRepository.find(id);
        if (group == null) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }
        return APIResult.ok(group);
    }

    public APIResult<Group> findNormalById(String id) {
        Group group = groupRepository.findNormalById(id, BaseStatusEnum.NORMAL);
        if (group == null) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }
        return APIResult.ok(group);
    }

    public APIResult<Page<Group>> search(Group group, Integer pageNo, Integer pageSize, LinkedHashMap<String, BaseOrderEnum> sort) {
        Long count = groupRepository.count(group);

        Page<Group> page = new Page<>(count, pageNo, pageSize);
        if (count == 0) {
            return APIResult.ok(page);
        }

        List<Group> groupList = groupRepository.find(group, page.getStart(), page.getPageSize(), JpaSortUtil.sort(sort));
        page.setList(groupList);

        return APIResult.ok(page);
    }

    public boolean exists(String code) {
        Long count = groupRepository.countByCode(code);
        return count > 0;
    }

    @Transactional
    public APIResult<Group> create(GroupDTO groupDTO) {
        String code = groupDTO.getCode();
        if (exists(code)) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

        Group group = convert(groupDTO);
        Group result = groupRepository.save(group);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Group> update(GroupDTO groupDTO) {
        Group group = convert(groupDTO);
        Group result = groupRepository.update(group);
        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Boolean> delete(String id) {
        Integer count = groupRepository.deleteById(id, BaseStatusEnum.DEL);
        return APIResult.ok(count > 0);
    }
}
