package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.product.ItemPriceDTO;
import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.util.ListUtil;
import cn.rankin.productservice.entity.CourseSubRelation;
import cn.rankin.productservice.entity.ItemPrice;
import cn.rankin.productservice.repository.ItemPriceRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.util.ArrayList;
import java.util.List;

import static cn.rankin.productservice.utils.DTOConverter.convert;

@Slf4j
@Service
public class ItemPriceService {

    @Autowired
    private ItemPriceRepository priceRepository;

    // 传过来的数组, 更新status为NORMAL, 没有传的但存在于数据库的更新为DEL
    @Transactional
    public APIResult<List<ItemPrice>> update(String itemId, List<ItemPriceDTO> priceDTOList) {
        List<ItemPrice> priceList = new ArrayList<>();

        if (priceDTOList == null) {
            return APIResult.ok();
        }else if (priceDTOList.size() == 0) {
            deleteByItemId(itemId);
            return APIResult.ok(priceList);
        }

        List<String> priceIdList = new ArrayList<>();
        for (int i = 0; i < priceDTOList.size(); i++) {
            ItemPriceDTO dto = priceDTOList.get(i);
            String priceId = dto.getId();
            if (priceId != null) {
                priceIdList.add(priceId);
            }
            ItemPrice itemPrice = convert(dto);
            itemPrice.setStatus(BaseStatusEnum.NORMAL);
            itemPrice.setSort(i);
            priceList.add(itemPrice);
        }

        if (priceIdList.size() > 0) {
            priceRepository.deleteExcludeId(priceIdList, BaseStatusEnum.DEL);
        }
        List<ItemPrice> result = priceRepository.save(priceList);

        return APIResult.ok(result);

    }

    @Transactional
    public Integer deleteByItemId(String itemId) {
        return priceRepository.deleteByItemId(itemId, BaseStatusEnum.DEL);
    }
}
